@@ -6,7 +6,7 @@ use strict;
 use 5.008003;
 no warnings 'utf8';
 
-our $VERSION = '1.016_03';
+our $VERSION = '1.016_04';
 
 
 
@@ -16,7 +16,7 @@ App::DBBrowser::DB - Database plugin documentation.
 
 =head1 VERSION
 
-Version 1.016_03
+Version 1.016_04
 
 =head1 DESCRIPTION
 
@@ -40,6 +40,7 @@ Supported plugin API versions: C<1.4> and C<1.5>.
 
 =head1 METHODS
 
+
 =head2 new
 
 The constructor method.
@@ -99,11 +100,13 @@ sub new {
     bless { Plugin => $plugin }, $class;
 }
 
+
 sub message_method_undef_return {
     my ( $self, $method ) = @_;
     return sprintf '%s method %s: no return value', ref $self->{Plugin}, $method;
 }
 
+
 sub debug {
     my ( $self, $dbh, $info, $opt, $db_opt ) = @_;
     return if ! $self->{Plugin}->can( 'debug' );
@@ -112,92 +115,6 @@ sub debug {
 
 
 
-
-=head2 create_table
-
-=over
-
-=item Arguments
-
-none
-
-=item return
-
-The primary-key-autoincrement statement.
-
-=back
-
-Example for the database driver C<Pg>:
-
-    sub primary_key_auto {
-        return "SERIAL PRIMARY KEY";
-    }
-
-=cut
-
-sub primary_key_auto {
-    my ( $self ) = @_;
-    return if ! $self->{Plugin}->can( 'primary_key_auto' );
-    return $self->{Plugin}->primary_key_auto();
-}
-
-
-
-=head2 create_table
-
-=over
-
-=item Arguments
-
-Database handle, quoted table name ( "schema"."table" ) and a reference to an array of arrays:
-    [ [ col name, col datatype ],
-      [ col name, col datatype ],
-      ...
-    ]
-The column name is already quoted.
-
-=item return
-
-nothing
-
-=back
-
-Creates a new table.
-
-=cut
-
-sub create_table {
-    my ( $self, $dbh, $table, $col_type ) = @_; #, $add_primay_key
-    my $ok = $self->{Plugin}->create_table( $dbh, $table, $col_type ); # , $add_primay_key
-    return $ok;
-}
-
-
-=head2 drop_table
-
-=over
-
-=item Arguments
-
-Database handle and a quoted table name ( "schema"."table" ).
-
-=item return
-
-nothing
-
-=back
-
-Drops the table.
-
-=cut
-
-sub drop_table {
-    my ( $self, $dbh, $table ) = @_;
-    my $ok = $self->{Plugin}->drop_table( $dbh, $table );
-    return $ok;
-}
-
-
 =head2 plugin_api_version
 
 =over
@@ -326,7 +243,6 @@ I<Fields> and I<Login Data>.
                           option "Login Data"  =>  $connect_parameter->{read_arg}
                                                =>  $connect_parameter->{keep_secret}
 
-
 =cut
 
 sub read_arguments {
@@ -603,6 +519,36 @@ sub get_table_names {
 
 
 
+=head2 primary_key_auto
+
+=over
+
+=item Arguments
+
+none
+
+=item return
+
+The primary-key-autoincrement statement.
+
+=back
+
+Example for the database driver C<Pg>:
+
+    sub primary_key_auto {
+        return "SERIAL PRIMARY KEY";
+    }
+
+=cut
+
+sub primary_key_auto {
+    my ( $self ) = @_;
+    return if ! $self->{Plugin}->can( 'primary_key_auto' ); #
+    return $self->{Plugin}->primary_key_auto();
+}
+
+
+
 =head2 column_names_and_types
 
 =over
